@@ -51,19 +51,216 @@ Helper::Helper(const QByteArray &name)
 }
 #endif
 
-//____________________________________________________________________
-QColor Helper::indicatorOutlineColor(const QPalette &palette, bool mouseOver, bool hasFocus, qreal opacity, AnimationMode mode, bool darkMode) const
+//
+QPalette Helper::palette(bool dark) const
 {
-    bool isDisabled = palette.currentColorGroup() == QPalette::Disabled;
+    QPalette palette;
 
-    if (isDisabled) {
-        return buttonOutlineColor(palette, mouseOver, hasFocus, opacity, mode, darkMode);
+    if (dark) {
+        // Colors defined in GTK adwaita style in _colors.scss
+        QColor base_color = lighten(desaturate(QColor("#241f31"), 1.0), 0.02);
+        QColor text_color = QColor("white");
+        QColor bg_color = darken(desaturate(QColor("#3d3846"), 1.0), 0.04);
+        QColor fg_color = QColor("#eeeeec");
+        QColor selected_bg_color = darken(QColor("#3584e4"), 0.2);
+        QColor selected_fg_color = QColor("white");
+        QColor osd_text_color = QColor("white");
+        QColor osd_bg_color = QColor("black");
+        QColor shadow = transparentize(QColor("black"), 0.9);
+
+        QColor backdrop_fg_color = mix(fg_color, bg_color);
+        QColor backdrop_base_color = lighten(base_color, 0.01);
+        QColor backdrop_selected_fg_color = mix(text_color, backdrop_base_color, 0.2);
+
+        // This is the color we use as initial color for the gradient in normal state
+        // Defined in _drawing.scss button(normal)
+        QColor button_base_color = darken(bg_color, 0.01);
+
+        QColor link_color = lighten(selected_bg_color, 0.2);
+        QColor link_visited_color = lighten(selected_bg_color, 0.1);
+
+        palette.setColor(QPalette::All,      QPalette::Window,          bg_color);
+        palette.setColor(QPalette::All,      QPalette::WindowText,      fg_color);
+        palette.setColor(QPalette::All,      QPalette::Base,            base_color);
+        palette.setColor(QPalette::All,      QPalette::AlternateBase,   base_color);
+        palette.setColor(QPalette::All,      QPalette::ToolTipBase,     osd_bg_color);
+        palette.setColor(QPalette::All,      QPalette::ToolTipText,     osd_text_color);
+        palette.setColor(QPalette::All,      QPalette::Text,            fg_color);
+        palette.setColor(QPalette::All,      QPalette::Button,          button_base_color);
+        palette.setColor(QPalette::All,      QPalette::ButtonText,      fg_color);
+        palette.setColor(QPalette::All,      QPalette::BrightText,      text_color);
+
+        palette.setColor(QPalette::All,      QPalette::Light,           lighten(button_base_color));
+        palette.setColor(QPalette::All,      QPalette::Midlight,        mix(lighten(button_base_color), button_base_color));
+        palette.setColor(QPalette::All,      QPalette::Mid,             mix(darken(button_base_color), button_base_color));
+        palette.setColor(QPalette::All,      QPalette::Dark,            darken(button_base_color));
+        palette.setColor(QPalette::All,      QPalette::Shadow,          shadow);
+
+        palette.setColor(QPalette::All,      QPalette::Highlight,       selected_bg_color);
+        palette.setColor(QPalette::All,      QPalette::HighlightedText, selected_fg_color);
+
+        palette.setColor(QPalette::All,      QPalette::Link,            link_color);
+        palette.setColor(QPalette::All,      QPalette::LinkVisited,     link_visited_color);
+
+
+        QColor insensitive_fg_color = mix(fg_color, bg_color);
+        QColor insensitive_bg_color = mix(bg_color, base_color, 0.4);
+
+        palette.setColor(QPalette::Disabled, QPalette::Window,          insensitive_bg_color);
+        palette.setColor(QPalette::Disabled, QPalette::WindowText,      insensitive_fg_color);
+        palette.setColor(QPalette::Disabled, QPalette::Base,            base_color);
+        palette.setColor(QPalette::Disabled, QPalette::AlternateBase,   base_color);
+        palette.setColor(QPalette::Disabled, QPalette::Text,            insensitive_fg_color);
+        palette.setColor(QPalette::Disabled, QPalette::Button,          insensitive_bg_color);
+        palette.setColor(QPalette::Disabled, QPalette::ButtonText,      insensitive_fg_color);
+        palette.setColor(QPalette::Disabled, QPalette::BrightText,      text_color);
+
+        palette.setColor(QPalette::Disabled, QPalette::Light,           lighten(insensitive_bg_color));
+        palette.setColor(QPalette::Disabled, QPalette::Midlight,        mix(lighten(insensitive_bg_color), insensitive_bg_color));
+        palette.setColor(QPalette::Disabled, QPalette::Mid,             mix(darken(insensitive_bg_color), insensitive_bg_color));
+        palette.setColor(QPalette::Disabled, QPalette::Dark,            darken(insensitive_bg_color));
+        palette.setColor(QPalette::Disabled, QPalette::Shadow,          shadow);
+
+        palette.setColor(QPalette::Disabled, QPalette::Highlight,       selected_bg_color);
+        palette.setColor(QPalette::Disabled, QPalette::HighlightedText, selected_fg_color);
+
+        palette.setColor(QPalette::Disabled, QPalette::Link,            link_color);
+        palette.setColor(QPalette::Disabled, QPalette::LinkVisited,     link_visited_color);
+
+
+        palette.setColor(QPalette::Inactive, QPalette::Window,          bg_color);
+        palette.setColor(QPalette::Inactive, QPalette::WindowText,      backdrop_fg_color);
+        palette.setColor(QPalette::Inactive, QPalette::Base,            backdrop_base_color);
+        palette.setColor(QPalette::Inactive, QPalette::AlternateBase,   backdrop_base_color);
+        palette.setColor(QPalette::Inactive, QPalette::Text,            backdrop_fg_color);
+        palette.setColor(QPalette::Inactive, QPalette::Button,          button_base_color);
+        palette.setColor(QPalette::Inactive, QPalette::ButtonText,      backdrop_fg_color);
+        palette.setColor(QPalette::Inactive, QPalette::BrightText,      text_color);
+
+        palette.setColor(QPalette::Inactive, QPalette::Light,           lighten(insensitive_bg_color));
+        palette.setColor(QPalette::Inactive, QPalette::Midlight,        mix(lighten(insensitive_bg_color), insensitive_bg_color));
+        palette.setColor(QPalette::Inactive, QPalette::Mid,             mix(darken(insensitive_bg_color), insensitive_bg_color));
+        palette.setColor(QPalette::Inactive, QPalette::Dark,            darken(insensitive_bg_color));
+        palette.setColor(QPalette::Inactive, QPalette::Shadow,          shadow);
+
+        palette.setColor(QPalette::Inactive, QPalette::Highlight,       selected_bg_color);
+        palette.setColor(QPalette::Inactive, QPalette::HighlightedText, backdrop_selected_fg_color);
+
+        palette.setColor(QPalette::Inactive, QPalette::Link,            link_color);
+        palette.setColor(QPalette::Inactive, QPalette::LinkVisited,     link_visited_color);
+    } else {
+        // Colors defined in GTK adwaita style in _colors.scss
+        QColor base_color = QColor("white");
+        QColor text_color = QColor("black");
+        QColor bg_color = QColor("#f6f5f4");
+        QColor fg_color = QColor("#2e3436");
+        QColor selected_bg_color = QColor("#3584e4");
+        QColor selected_fg_color = QColor("white");
+        QColor osd_text_color = QColor("white");
+        QColor osd_bg_color = QColor("black");
+        QColor shadow = transparentize(QColor("black"), 0.9);
+
+        QColor backdrop_fg_color = mix(fg_color, bg_color);
+        QColor backdrop_base_color = darken(base_color, 0.01);
+        QColor backdrop_selected_fg_color = backdrop_base_color;
+
+        // This is the color we use as initial color for the gradient in normal state
+        // Defined in _drawing.scss button(normal)
+        QColor button_base_color = darken(bg_color, 0.04);
+
+        QColor link_color = darken(selected_bg_color, 0.1);
+        QColor link_visited_color = darken(selected_bg_color, 0.2);
+
+        palette.setColor(QPalette::All,      QPalette::Window,          bg_color);
+        palette.setColor(QPalette::All,      QPalette::WindowText,      fg_color);
+        palette.setColor(QPalette::All,      QPalette::Base,            base_color);
+        palette.setColor(QPalette::All,      QPalette::AlternateBase,   base_color);
+        palette.setColor(QPalette::All,      QPalette::ToolTipBase,     osd_bg_color);
+        palette.setColor(QPalette::All,      QPalette::ToolTipText,     osd_text_color);
+        palette.setColor(QPalette::All,      QPalette::Text,            fg_color);
+        palette.setColor(QPalette::All,      QPalette::Button,          button_base_color);
+        palette.setColor(QPalette::All,      QPalette::ButtonText,      fg_color);
+        palette.setColor(QPalette::All,      QPalette::BrightText,      text_color);
+
+        palette.setColor(QPalette::All,      QPalette::Light,           lighten(button_base_color));
+        palette.setColor(QPalette::All,      QPalette::Midlight,        mix(lighten(button_base_color), button_base_color));
+        palette.setColor(QPalette::All,      QPalette::Mid,             mix(darken(button_base_color), button_base_color));
+        palette.setColor(QPalette::All,      QPalette::Dark,            darken(button_base_color));
+        palette.setColor(QPalette::All,      QPalette::Shadow,          shadow);
+
+        palette.setColor(QPalette::All,      QPalette::Highlight,       selected_bg_color);
+        palette.setColor(QPalette::All,      QPalette::HighlightedText, selected_fg_color);
+
+        palette.setColor(QPalette::All,      QPalette::Link,            link_color);
+        palette.setColor(QPalette::All,      QPalette::LinkVisited,     link_visited_color);
+
+        QColor insensitive_fg_color = mix(fg_color, bg_color);
+        QColor insensitive_bg_color = mix(bg_color, base_color, 0.4);
+
+        palette.setColor(QPalette::Disabled, QPalette::Window,          insensitive_bg_color);
+        palette.setColor(QPalette::Disabled, QPalette::WindowText,      insensitive_fg_color);
+        palette.setColor(QPalette::Disabled, QPalette::Base,            base_color);
+        palette.setColor(QPalette::Disabled, QPalette::AlternateBase,   base_color);
+        palette.setColor(QPalette::Disabled, QPalette::Text,            insensitive_fg_color);
+        palette.setColor(QPalette::Disabled, QPalette::Button,          insensitive_bg_color);
+        palette.setColor(QPalette::Disabled, QPalette::ButtonText,      insensitive_fg_color);
+        palette.setColor(QPalette::Disabled, QPalette::BrightText,      text_color);
+
+        palette.setColor(QPalette::Disabled, QPalette::Light,           lighten(insensitive_bg_color));
+        palette.setColor(QPalette::Disabled, QPalette::Midlight,        mix(lighten(insensitive_bg_color), insensitive_bg_color));
+        palette.setColor(QPalette::Disabled, QPalette::Mid,             mix(darken(insensitive_bg_color), insensitive_bg_color));
+        palette.setColor(QPalette::Disabled, QPalette::Dark,            darken(insensitive_bg_color));
+        palette.setColor(QPalette::Disabled, QPalette::Shadow,          shadow);
+
+        palette.setColor(QPalette::Disabled, QPalette::Highlight,       selected_bg_color);
+        palette.setColor(QPalette::Disabled, QPalette::HighlightedText, selected_fg_color);
+
+        palette.setColor(QPalette::Disabled, QPalette::Link,            link_color);
+        palette.setColor(QPalette::Disabled, QPalette::LinkVisited,     link_visited_color);
+
+
+        palette.setColor(QPalette::Inactive, QPalette::Window,          bg_color);
+        palette.setColor(QPalette::Inactive, QPalette::WindowText,      backdrop_fg_color);
+        palette.setColor(QPalette::Inactive, QPalette::Base,            backdrop_base_color);
+        palette.setColor(QPalette::Inactive, QPalette::AlternateBase,   backdrop_base_color);
+        palette.setColor(QPalette::Inactive, QPalette::Text,            backdrop_fg_color);
+        palette.setColor(QPalette::Inactive, QPalette::Button,          button_base_color);
+        palette.setColor(QPalette::Inactive, QPalette::ButtonText,      backdrop_fg_color);
+        palette.setColor(QPalette::Inactive, QPalette::BrightText,      text_color);
+
+        palette.setColor(QPalette::Inactive, QPalette::Light,           lighten(insensitive_bg_color));
+        palette.setColor(QPalette::Inactive, QPalette::Midlight,        mix(lighten(insensitive_bg_color), insensitive_bg_color));
+        palette.setColor(QPalette::Inactive, QPalette::Mid,             mix(darken(insensitive_bg_color), insensitive_bg_color));
+        palette.setColor(QPalette::Inactive, QPalette::Dark,            darken(insensitive_bg_color));
+        palette.setColor(QPalette::Inactive, QPalette::Shadow,          shadow);
+
+        palette.setColor(QPalette::Inactive, QPalette::Highlight,       selected_bg_color);
+        palette.setColor(QPalette::Inactive, QPalette::HighlightedText, backdrop_selected_fg_color);
+
+        palette.setColor(QPalette::Inactive, QPalette::Link,            link_color);
+        palette.setColor(QPalette::Inactive, QPalette::LinkVisited,     link_visited_color);
     }
 
-    if (darkMode) {
-        return darken(palette.color(QPalette::Window), 0.18);
+    return palette;
+}
+
+//____________________________________________________________________
+QColor Helper::indicatorOutlineColor(const QPalette &palette, bool mouseOver, bool hasFocus, qreal opacity, AnimationMode mode, CheckBoxState state, bool darkMode, bool inMenu) const
+{
+    bool isDisabled = palette.currentColorGroup() == QPalette::Disabled;
+    if (inMenu || state == CheckBoxState::CheckOff) {
+
+        if (isDisabled) {
+            return buttonOutlineColor(palette, mouseOver, hasFocus, opacity, mode, darkMode);
+        }
+
+        if (darkMode) {
+            return darken(palette.color(QPalette::Window), 0.18);
+        } else {
+            return darken(palette.color(QPalette::Window), 0.24);
+        }
     } else {
-        return darken(palette.color(QPalette::Window), 0.24);
+        return palette.color(QPalette::Highlight);
     }
 }
 
@@ -196,50 +393,59 @@ QColor Helper::buttonBackgroundColor(const QPalette &palette, bool mouseOver, bo
 }
 
 //
-QColor Helper::indicatorBackgroundColor(const QPalette &palette, bool mouseOver, bool hasFocus, bool sunken, qreal opacity, AnimationMode mode, bool darkMode) const
+QColor Helper::indicatorBackgroundColor(const QPalette &palette, bool mouseOver, bool hasFocus, bool sunken, qreal opacity, AnimationMode mode, CheckBoxState state, bool darkMode, bool inMenu) const
 {
     bool isDisabled = palette.currentColorGroup() == QPalette::Disabled;
     QColor background(palette.color(QPalette::Window));
     // Normal-alt button for dark mode is darken(bg_color, 0.03)
     // Normal-alt button for normal mode is lighten(bg_color, 0.05)
     QColor indicatorColor(darkMode ? darken(background, 0.03) : lighten(background, 0.05));
-    if (isDisabled) {
-        // Defined in drawing.css - insensitive button
-        // $insensitive_bg_color: mix($bg_color, $base_color, 60%);
-        return mix(palette.color(QPalette::Active, QPalette::Window), palette.color(QPalette::Active, QPalette::Base), 0.6);
-    }
 
-    if (mode == AnimationPressed) {
-        if (darkMode) {
-            // Active button for dark mode is darken(bg_color, 0.09)
-            return mix(background, darken(background, 0.09), opacity);
-        } else {
-            // Active button for normal mode is darken(bg_color, 0.14)
-            return mix(lighten(background, 0.0), darken(background, 0.14), opacity);
+    if (inMenu || state == CheckOff) {
+        if (isDisabled) {
+            // Defined in drawing.css - insensitive button
+            // $insensitive_bg_color: mix($bg_color, $base_color, 60%);
+            return mix(palette.color(QPalette::Active, QPalette::Window), palette.color(QPalette::Active, QPalette::Base), 0.6);
         }
-    } else if (sunken) {
-        if (darkMode) {
-            // Active button for dark mode is darken(bg_color, 0.09)
-            return darken(background, 0.09);
-        } else {
-            // Active button for normal mode is darken(bg_color, 0.14)
-            return darken(background, 0.14);
+
+        if (mode == AnimationPressed) {
+            if (darkMode) {
+                // Active button for dark mode is darken(bg_color, 0.09)
+                return mix(background, darken(background, 0.09), opacity);
+            } else {
+                // Active button for normal mode is darken(bg_color, 0.14)
+                return mix(lighten(background, 0.0), darken(background, 0.14), opacity);
+            }
+        } else if (sunken) {
+            if (darkMode) {
+                // Active button for dark mode is darken(bg_color, 0.09)
+                return darken(background, 0.09);
+            } else {
+                // Active button for normal mode is darken(bg_color, 0.14)
+                return darken(background, 0.14);
+            }
+        } else if (mode == AnimationHover) {
+            if (darkMode) {
+                // Hovered-alt button for dark mode is bg_color
+                return mix(indicatorColor, background, opacity);
+            } else {
+                // Hovered-alt button for normal mode is lighten(bg_color, 0.09)
+                return mix(indicatorColor, lighten(background, 0.09), opacity);
+            }
+        } else if (mouseOver) {
+            if (darkMode) {
+                // Hovered-alt button for dark mode is bg_color
+                return background;
+            } else {
+                // Hovered-alt button for normal mode is lighten(bg_color, 0.09)
+                return lighten(background, 0.09);
+            }
         }
-    } else if (mode == AnimationHover) {
+    } else {
         if (darkMode) {
-            // Hovered-alt button for dark mode is bg_color
-            return mix(indicatorColor, background, opacity);
+            return lighten(palette.color(QPalette::Highlight));
         } else {
-            // Hovered-alt button for normal mode is lighten(bg_color, 0.09)
-            return mix(indicatorColor, lighten(background, 0.09), opacity);
-        }
-    } else if (mouseOver) {
-        if (darkMode) {
-            // Hovered-alt button for dark mode is bg_color
-            return background;
-        } else {
-            // Hovered-alt button for normal mode is lighten(bg_color, 0.09)
-            return lighten(background, 0.09);
+            return palette.color(QPalette::Highlight);
         }
     }
 
@@ -308,13 +514,22 @@ QColor Helper::scrollBarHandleColor(const QPalette &palette, bool mouseOver, boo
 }
 
 //______________________________________________________________________________
-QColor Helper::checkBoxIndicatorColor(const QPalette &palette, bool mouseOver, bool active, qreal opacity, AnimationMode mode) const
+QColor Helper::checkBoxIndicatorColor(const QPalette &palette, bool mouseOver, bool active, qreal opacity, AnimationMode mode, bool darkMode, bool inMenu) const
 {
     Q_UNUSED(mouseOver);
     Q_UNUSED(active);
     Q_UNUSED(opacity);
     Q_UNUSED(mode);
-    return palette.text().color();
+
+    if (inMenu) {
+        return palette.color(QPalette::Text);
+    } else {
+        if (active) {
+            return palette.color(QPalette::HighlightedText);
+        } else {
+            return transparentize(palette.color(QPalette::ToolTipText), 0.2);
+        }
+    }
 }
 
 //______________________________________________________________________________
@@ -609,15 +824,9 @@ void Helper::renderButtonFrame(QPainter *painter, const QRect &rect, const QColo
     if (color.isValid() && active) {
         QLinearGradient gradient(frameRect.bottomLeft(), frameRect.topLeft());
         if (sunken) {
-                // Pressed button in dark mode is not a gradient, just an image consting from same $color
-            if (darkMode) {
-                gradient.setColorAt(0, color);
-                gradient.setColorAt(1, color);
-            } else {
-                // Pressed button in normal mode is not a gradient, just an image consting from same $color
-                gradient.setColorAt(0, color);
-                gradient.setColorAt(1, color);
-            }
+            // Pressed button in normal and dark mode is not a gradient, just an image consting from same $color
+            gradient.setColorAt(0, color);
+            gradient.setColorAt(1, color);
         } else if (mouseOver) {
             if (darkMode) {
                 QColor baseColor = lighten(color, 0.01);
@@ -663,7 +872,7 @@ void Helper::renderButtonFrame(QPainter *painter, const QRect &rect, const QColo
 
 //______________________________________________________________________________
 void Helper::renderCheckBoxFrame(QPainter *painter, const QRect &rect, const QColor &color, const QColor &outline, const QColor &shadow,
-                               bool hasFocus, bool sunken, bool mouseOver, bool active, bool darkMode) const
+                               bool hasFocus, bool sunken, bool mouseOver, bool active, CheckBoxState state, bool darkMode, bool inMenu) const
 {
     // setup painter
     painter->setRenderHint(QPainter::Antialiasing, true);
@@ -681,60 +890,64 @@ void Helper::renderCheckBoxFrame(QPainter *painter, const QRect &rect, const QCo
     } else
         painter->setPen(Qt::NoPen);
 
-    // content
-    if (color.isValid() && active) {
-        QLinearGradient gradient(frameRect.bottomLeft(), frameRect.topLeft());
-        if (sunken) {
-                // Pressed-alt button in dark mode is not a gradient, just an image consting from same $color
-            if (darkMode) {
-                gradient.setColorAt(0, color);
-                gradient.setColorAt(1, color);
+    if (inMenu || state == CheckOff) {
+        // content
+        if (color.isValid() && active) {
+            QLinearGradient gradient(frameRect.bottomLeft(), frameRect.topLeft());
+            if (sunken) {
+                    // Pressed-alt button in dark mode is not a gradient, just an image consting from same $color
+                if (darkMode) {
+                    gradient.setColorAt(0, color);
+                    gradient.setColorAt(1, color);
+                } else {
+                    // Pressed-alt button in normal mode is not a gradient, just an image consting from same $color
+                    gradient.setColorAt(0, color);
+                    gradient.setColorAt(1, color);
+                }
+            } else if (mouseOver) {
+                if (darkMode) {
+                    QColor baseColor = color;
+                    // Hovered-alt button in dark mode is a gradient from $color to darken(bg_color, 0.04)
+                    gradient.setColorAt(0, darken(baseColor, 0.04));
+                    gradient.setColorAt(1, color);
+                } else {
+                    QColor baseColor = darken(color, 0.09);
+                    // Hovered-alt button in normal mode is a gradient from $color to lighten(bg_color, 0.04)
+                    gradient.setColorAt(0, color);                      // FIXME:
+                    gradient.setColorAt(1, lighten(baseColor, 0.04));   // should be vice-versa, but this way it seems to be more accurate
+                }
             } else {
-                // Pressed-alt button in normal mode is not a gradient, just an image consting from same $color
-                gradient.setColorAt(0, color);
-                gradient.setColorAt(1, color);
-            }
-        } else if (mouseOver) {
-            if (darkMode) {
-                QColor baseColor = color;
-                // Hovered-alt button in dark mode is a gradient from $color to darken(bg_color, 0.04)
-                gradient.setColorAt(0, darken(baseColor, 0.04));
-                gradient.setColorAt(1, color);
-            } else {
-                QColor baseColor = darken(color, 0.09);
-                // Hovered-alt button in normal mode is a gradient from $color to lighten(bg_color, 0.04)
-                gradient.setColorAt(0, color);                      // FIXME:
-                gradient.setColorAt(1, lighten(baseColor, 0.04));   // should be vice-versa, but this way it seems to be more accurate
+                if (darkMode) {
+                    QColor baseColor = lighten(color, 0.03);
+                    // Normal-alt button in dark mode is a gradient from $color to darken(bg_color, 0.06)
+                    gradient.setColorAt(0, darken(baseColor, 0.06));
+                    gradient.setColorAt(1, color);
+                } else {
+                    QColor baseColor = darken(color, 0.05);
+                    // Normal-alt button in normal mode is a gradient from $color to bg_color
+                    gradient.setColorAt(0, baseColor);
+                    gradient.setColorAt(1, color);
+                }
             }
+            painter->setBrush(gradient);
+        } else if (!active) {
+            painter->setBrush(color);
         } else {
-            if (darkMode) {
-                QColor baseColor = lighten(color, 0.03);
-                // Normal-alt button in dark mode is a gradient from $color to darken(bg_color, 0.06)
-                gradient.setColorAt(0, darken(baseColor, 0.06));
-                gradient.setColorAt(1, color);
-            } else {
-                QColor baseColor = darken(color, 0.05);
-                // Normal-alt button in normal mode is a gradient from $color to bg_color
-                gradient.setColorAt(0, baseColor);
-                gradient.setColorAt(1, color);
-            }
+            painter->setBrush(Qt::NoBrush);
         }
-        painter->setBrush(gradient);
-    } else if (!active) {
-        painter->setBrush(color);
     } else {
-        painter->setBrush(Qt::NoBrush);
+        if (color.isValid()) {
+            QLinearGradient gradient(frameRect.bottomLeft(), frameRect.topLeft());
+            gradient.setColorAt(0, color);
+            gradient.setColorAt(1, lighten(color, 0.04));
+            painter->setBrush(gradient);
+        } else {
+            painter->setBrush(Qt::NoBrush);
+        }
     }
 
     // render
     painter->drawRoundedRect(frameRect, radius, radius);
-
-    if (!sunken && active && color.isValid()) {
-        painter->setPen(color.lighter(140));
-        painter->drawLine(frameRect.topLeft() + QPoint(3, 1), frameRect.topRight() + QPoint(-3, 1));
-        painter->setPen(outline.darker(114));
-        painter->drawLine(frameRect.bottomLeft() + QPointF(2.7, 0), frameRect.bottomRight() + QPointF(-2.7, 0));
-    }
 }
 
 //______________________________________________________________________________
@@ -940,7 +1153,7 @@ void Helper::renderCheckBoxBackground(QPainter *painter, const QRect &rect, cons
 
 //______________________________________________________________________________
 void Helper::renderCheckBox(QPainter *painter, const QRect &rect, const QColor &background, const QColor &outline, const QColor &tickColor,
-                            bool sunken, CheckBoxState state, bool mouseOver, qreal animation, bool active, bool darkMode) const
+                            bool sunken, CheckBoxState state, bool mouseOver, qreal animation, bool active, bool darkMode, bool inMenu) const
 {
     // setup painter
     painter->save();
@@ -953,7 +1166,7 @@ void Helper::renderCheckBox(QPainter *painter, const QRect &rect, const QColor &
 
     // content
     {
-        renderCheckBoxFrame(painter, rect, background, outline, Qt::transparent, false, sunken, mouseOver, active, darkMode);
+        renderCheckBoxFrame(painter, rect, background, outline, Qt::transparent, false, sunken, mouseOver, active, state, darkMode, inMenu);
     }
 
     // mark
@@ -968,9 +1181,9 @@ void Helper::renderCheckBox(QPainter *painter, const QRect &rect, const QColor &
         QRectF markerRect(frameRect);
 
         QPainterPath path;
-        path.moveTo(markerRect.right(), markerRect.top() + markerRect.height() / 4);
+        path.moveTo(markerRect.right() - markerRect.width() / 4, markerRect.top() + markerRect.height() / 3);
         path.lineTo(markerRect.center().x(), markerRect.bottom() - markerRect.height() / 3.0);
-        path.lineTo(markerRect.left() + markerRect.width() / 3.0, markerRect.center().y());
+        path.lineTo(markerRect.left() + markerRect.width() / 4, markerRect.center().y());
 
         painter->setClipRect(markerRect);
         painter->drawPath(path);
@@ -994,9 +1207,9 @@ void Helper::renderCheckBox(QPainter *painter, const QRect &rect, const QColor &
         QRectF markerRect(frameRect);
 
         QPainterPath path;
-        path.moveTo(markerRect.right(), markerRect.top() + markerRect.height() / 4);
+        path.moveTo(markerRect.right() - markerRect.width() / 4, markerRect.top() + markerRect.height() / 3);
         path.lineTo(markerRect.center().x(), markerRect.bottom() - markerRect.height() / 3.0);
-        path.lineTo(markerRect.left() + markerRect.width() / 3.0, markerRect.center().y());
+        path.lineTo(markerRect.left() + markerRect.width() / 4, markerRect.center().y());
         path.translate(-markerRect.right(), -markerRect.top());
 
         painter->setClipRect(markerRect.adjusted(1, 1, -1, -1));
@@ -1028,7 +1241,7 @@ void Helper::renderRadioButtonBackground(QPainter *painter, const QRect &rect, c
 
 //______________________________________________________________________________
 void Helper::renderRadioButton(QPainter *painter, const QRect &rect, const QColor &background, const QColor &outline, const QColor &tickColor,
-                               bool sunken, bool enabled, RadioButtonState state, qreal animation, bool mouseOver, bool darkMode) const
+                               bool sunken, bool enabled, RadioButtonState state, qreal animation, bool mouseOver, bool darkMode, bool inMenu) const
 {
     // setup painter
     painter->setRenderHint(QPainter::Antialiasing, true);
@@ -1037,20 +1250,13 @@ void Helper::renderRadioButton(QPainter *painter, const QRect &rect, const QColo
     QRectF frameRect(rect);
     frameRect.adjust(2, 2, -2, -2);
 
-    // content
-    {
+    if (inMenu || state == RadioOff) {
         if (background.isValid() && enabled) {
             QLinearGradient gradient(frameRect.bottomLeft(), frameRect.topLeft());
             if (sunken) {
-                    // Pressed-alt button in dark mode is not a gradient, just an image consting from same $background
-                if (darkMode) {
-                    gradient.setColorAt(0, background);
-                    gradient.setColorAt(1, background);
-                } else {
-                    // Pressed-alt button in normal mode is not a gradient, just an image consting from same $background
-                    gradient.setColorAt(0, background);
-                    gradient.setColorAt(1, background);
-                }
+                // Pressed-alt button in normal and dark mode is not a gradient, just an image consting from same $background
+                gradient.setColorAt(0, background);
+                gradient.setColorAt(1, background);
             } else if (mouseOver) {
                 if (darkMode) {
                     QColor baseColor = background;
@@ -1085,6 +1291,20 @@ void Helper::renderRadioButton(QPainter *painter, const QRect &rect, const QColo
 
         painter->setPen(QPen(outline, 1));
 
+        QRectF contentRect(frameRect.adjusted(0.5, 0.5, -0.5, -0.5));
+        painter->drawEllipse(contentRect);
+    } else {
+        if (background.isValid()) {
+            QLinearGradient gradient(frameRect.bottomLeft(), frameRect.topLeft());
+            gradient.setColorAt(0, background);
+            gradient.setColorAt(1, lighten(background, 0.04));
+            painter->setBrush(gradient);
+        } else {
+            painter->setBrush(Qt::NoBrush);
+        }
+
+        painter->setPen(QPen(outline, 1));
+
         QRectF contentRect(frameRect.adjusted(0.5, 0.5, -0.5, -0.5));
         painter->drawEllipse(contentRect);
     }
@@ -1204,15 +1424,9 @@ void Helper::renderSliderHandle(QPainter *painter, const QRect &rect, const QCol
     if (color.isValid() && enabled) {
         QLinearGradient gradient(frameRect.bottomLeft(), frameRect.topLeft());
         if (sunken) {
-                // Pressed-alt button in dark mode is not a gradient, just an image consting from same $background
-            if (darkMode) {
-                gradient.setColorAt(0, color);
-                gradient.setColorAt(1, color);
-            } else {
-                // Pressed-alt button in normal mode is not a gradient, just an image consting from same $color
-                gradient.setColorAt(0, color);
-                gradient.setColorAt(1, color);
-            }
+            // Pressed-alt button in normal and dark mode is not a gradient, just an image consting from same $background
+            gradient.setColorAt(0, color);
+            gradient.setColorAt(1, color);
         } else {
             if (darkMode) {
                 QColor baseColor = lighten(color, 0.03);
@@ -1694,10 +1908,14 @@ void Helper::setVariant(QWidget *widget, const QByteArray &variant)
             XcbAtom atom;
         };
 
-        typedef void *(*XcbConnectFn)(int, int);
-        typedef XcbInternAtomCookie(*XcbInternAtomFn)(void *, int, int, const char *);
-        typedef XcbInternAtomReply * (*XcbInternAtomReplyFn)(void *, XcbInternAtomCookie, int);
-        typedef int (*XcbChangePropertyFn)(void *, int, int, XcbAtom, XcbAtom, int, int, const void *);
+        struct XcbVoidCookie {
+            unsigned int sequence;
+        };
+
+        typedef void *(*XcbConnectFn)(const char *, int *);
+        typedef XcbInternAtomCookie(*XcbInternAtomFn)(void *, quint8, quint16, const char *);
+        typedef XcbInternAtomReply * (*XcbInternAtomReplyFn)(void *, XcbInternAtomCookie, void *);
+        typedef XcbVoidCookie (*XcbChangePropertyFn)(void *, quint8, quint32, XcbAtom, XcbAtom, quint8, quint32, const void *);
         typedef int (*XcbFlushFn)(void *);
 
         static QLibrary *lib = 0;
